pub enum Feature {
Show 35 variants
AndroidSerialno,
AndroidBootreason,
AspectRatio,
Container,
CustomArtifacts,
Ashmem,
BootNotifier,
BootNotifierCpuBoost,
Framebuffer,
Gralloc,
Kgsl,
Magma,
MagmaSupportedVendors,
Nanohub,
Fastrpc,
NetworkManager,
Gfxstream,
Bpf,
EnableSuid,
IoUring,
ErrorOnFailedReboot,
Perfetto,
PingGroupRange,
RootfsRw,
Selinux,
SelinuxTestSuite,
TestData,
Thermal,
Cooling,
HvdcpOpti,
Wifi,
AdditionalMounts,
WakeupTest,
MmcblkStub,
FakeIon,
}Expand description
Features are a way to enable or disable specific starnix behaviors.
These are specified in the component manifest of the starnix container, or explicitly provided to the kernel constructor in tests.
Variants
AndroidSerialno
AndroidBootreason
AspectRatio
Container
CustomArtifacts
Ashmem
BootNotifier
BootNotifierCpuBoost
Framebuffer
Gralloc
Kgsl
Magma
MagmaSupportedVendors
Nanohub
Fastrpc
NetworkManager
Gfxstream
Bpf
EnableSuid
IoUring
ErrorOnFailedReboot
Perfetto
PingGroupRange
RootfsRw
Selinux
SelinuxTestSuite
TestData
Thermal
Cooling
HvdcpOpti
Wifi
AdditionalMounts
WakeupTest
MmcblkStub
FakeIon
Implementations